--- org.el	2013-01-11 21:34:28.340999307 +0100
+++ ../../../snps/org.el	2013-01-11 21:42:18.133011339 +0100
@@ -154,6 +154,12 @@
 ;; load languages based on value of `org-babel-load-languages'
 (defvar org-babel-load-languages)
 
+(defvar org-agenda-overriding-agenda-format nil)
+(make-variable-buffer-local 'org-agenda-overriding-agenda-format)
+
+(defvar org-agenda-property-list nil)
+(make-variable-buffer-local 'org-agenda-property-list)
+
 ;;;###autoload
 (defun org-babel-do-load-languages (sym value)
   "Load the languages defined in `org-babel-load-languages'."
@@ -13406,6 +13412,16 @@
 			  (or (not org-agenda-tags-todo-honor-ignore-options)
 			      (not (org-agenda-check-for-timestamp-as-reason-to-ignore-todo-item))))))
 
+	    ;; extract properties
+	    (if org-agenda-property-list
+		(setq prop-list
+		      (mapcar
+		       '(lambda (prop)
+			  (cons prop (or (org-entry-get (point) prop 'inherit)
+					 "not set"
+					 ""))) org-agenda-property-list))
+	      (setq prop-list ""))
+	    
 	    ;; select this headline
 	    (cond
 	     ((eq action 'sparse-tree)
@@ -13415,15 +13431,22 @@
 		    (match-beginning 1) (match-end 1)))
 	      (org-show-context 'tags-tree))
 	     ((eq action 'agenda)
-	      (setq txt (org-agenda-format-item
-			 ""
-			 (concat
-			  (if (eq org-tags-match-list-sublevels 'indented)
-			      (make-string (1- level) ?.) "")
-			  (org-get-heading))
-			 level category
-			 tags-list)
-		    priority (org-get-priority txt))
+	      (if org-agenda-overriding-agenda-format
+		  (setq txt (funcall org-agenda-overriding-agenda-format
+				     (org-get-heading 'no-tags 'no-todo)
+				     level
+				     category
+				     tags-list
+				     prop-list))
+		(setq txt (org-agenda-format-item
+			   ""
+			   (concat
+			    (if (eq org-tags-match-list-sublevels 'indented)
+				(make-string (1- level) ?.) "")
+			    (org-get-heading))
+			   level category
+			   tags-list)))
+	      (setq priority (org-get-priority txt))
 	      (goto-char lspos)
 	      (setq marker (org-agenda-new-marker))
 	      (org-add-props txt props
